<?php

/**
 * Elementor Widget
 * @package Meditest
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class meditest_faq_accordion extends Widget_Base
{

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name()
	{
		return 'main-top-slider';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title()
	{
		return esc_html__('FAQ Accordion', 'meditest-extra');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon()
	{
		return 'fas fa-th-large';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories()
	{
		return ['meditest_widgets'];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */


	protected function register_controls()
	{
		$this->layout_options();
	}

	/**
	 * Layout Options
	 */
	private function layout_options()
	{


		$this->start_controls_section(
			'layout_option',
			[
				'label' => __('Layout Options', 'meditest-extra'),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'faq_style',
			[
				'label' => esc_html__('Select Style', 'textdomain'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'border',
				'options' => [
					'border'  => esc_html__('Border Style', 'textdomain'),
					'shadow' => esc_html__('Shadow Style', 'textdomain'),
				],
			]
		);


		$repeater = new Repeater();


		$repeater->add_control(
			'faq_title',
			[
				'label' => esc_html__('FAQ Title', 'textdomain'),
				'type' => Controls_Manager::TEXTAREA,
				'rows' => 2,
				'default' => esc_html__('How to make an appointment at Dentata?', 'textdomain'),
			]
		);

		$repeater->add_control(
			'faq_desc',
			[
				'label' => esc_html__('FAQ Description', 'textdomain'),
				'type' => Controls_Manager::TEXTAREA,
				'rows' => 2,
				'default' => esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit venenatis tempus orci ut lacinia. Sed tempor hendrerit fermentum Pellentesque.', 'textdomain'),
			]
		);


		$this->add_control(
			'faq_lists',
			[
				'label' => esc_html__('Slider Image List', 'meditest-extra'),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'faq_title' => esc_html__('Best Service', 'meditest-extra'),
					],
				],
				'title_field' => '{{{ faq_title }}}',
			]
		);





		$this->end_controls_section();
	}

	protected function render()
	{

		$settings = $this->get_settings_for_display();

		$faq_lists = $settings['faq_lists'];

		$faq_style = $settings['faq_style'];

		$faq_bg_style = ($faq_style == 'shadow') ? 'shadow_bg' : '';

?>





		<div class="meditest-faq-accordion">
			<div id="accordion">

				<?php foreach ($faq_lists as $key => $faq_list) { ?>

					<div class="card <?php echo esc_attr($faq_bg_style); ?>">
						<div class="card-header" id="headingOne">
							<h5 class="mb-0">
								<button class="btn btn-link" data-toggle="collapse" data-target="#elementor-repeater-item-<?php echo esc_attr($faq_list['_id']); ?>" aria-expanded="true" aria-controls="elementor-repeater-item-<?php echo esc_attr($faq_list['_id']); ?>">
									<?php echo esc_html($faq_list['faq_title']); ?>
								</button>
							</h5>
						</div>

						<div id="elementor-repeater-item-<?php echo esc_attr($faq_list['_id']); ?>" class="collapse <?php if ($key == 0) {
																														echo esc_attr('show');
																													}  ?>" aria-labelledby="headingOne" data-parent="#accordion">
							<div class="card-body">
								<?php echo esc_html($faq_list['faq_desc']); ?>
							</div>
						</div>
					</div>

				<?php } ?>

			</div>
		</div>


<?php
	}
}

Plugin::instance()->widgets_manager->register_widget_type(new meditest_faq_accordion());
