<?php

/**
 * Elementor Widget
 * @package Meditest
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class meditest_latest_post_grid extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'latest-post-grid';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return esc_html__('Latest Posts Grid', 'meditest-extra');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'fas fa-th-large';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['meditest_widgets'];
    }

    /**
     * Register Elementor widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     * @access protected
     */


    protected function register_controls()
    {
        $this->layout_options();
        $this->post_query_options();
        $this->meta_options();
        $this->design_options();
    }

    /**
     * Layout Options
     */
    private function layout_options()
    {


        $this->start_controls_section(
            'layout_option',
            [
                'label' => __('Layout Options', 'meditest-extra'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'layout_style',
            [
                'label' => esc_html__('Select Layout Style', 'textdomain'),
                'type' => Controls_Manager::SELECT,
                'default' => 'st_one',
                'options' => [
                    'st_one' => esc_html__('Layout Style One', 'textdomain'),
                    'st_two'  => esc_html__('Layout Style Two', 'textdomain'),
                    'st_three'  => esc_html__('Layout Style Three', 'textdomain'),
                    'st_four'  => esc_html__('Layout Style Four', 'textdomain'),
                ],
            ]
        );

        $this->add_control(
            'grid_post_column',
            [
                'label'     => esc_html__('Select Grid Column', 'foodco'),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'col-lg-6 col-lg-4',
                'options'   => [
                    'col-lg-12'    => esc_html__('1 Columns', 'foodco'),
                    'col-lg-6'    => esc_html__('2 Columns', 'foodco'),
                    'col-md-6 col-lg-4'    => esc_html__('3 Columns', 'foodco'),
                    'col-md-6 col-lg-3'    => esc_html__('4 Columns', 'foodco'),
                ],
            ]
        );


        $this->add_responsive_control(
            'grid_img_height',
            [
                'label' => esc_html__('Set Post Image Height', 'meditest-extra'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                    ],
                ],
                'devices' => ['desktop', 'tablet', 'mobile'],
                'desktop_default' => [
                    'size' => 280,
                    'unit' => 'px',
                ],
                'tablet_default' => [
                    'size' => 232,
                    'unit' => 'px',
                ],
                'mobile_default' => [
                    'size' => 232,
                    'unit' => 'px',
                ],

                'default'  => [
                    'unit' => 'px',
                    'size' => 280,
                ],

                'selectors' => [
                    '{{WRAPPER}} .theme-post-grid-design-one .post-block-col-one .news-post-grid-thumbnail-wrap img,
                    {{WRAPPER}} .post-block-col-one .news-post-grid-thumbnail' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );


        $this->end_controls_section();
    }

    /**
     * Post Query Options
     */
    private function post_query_options()
    {


        $this->start_controls_section(
            'post_query_option',
            [
                'label' => __('Post Options', 'meditest-extra'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'post_sortby',
            [
                'label'     => esc_html__('Post sort by', 'meditest-extra'),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'latestpost',
                'options'   => [
                    'latestpost'      => esc_html__('Latest posts', 'meditest-extra'),
                    //'popularposts'    => esc_html__('Popular posts', 'meditest-extra'),
                    'mostdiscussed'    => esc_html__('Most discussed', 'meditest-extra'),
                    'title'       => esc_html__('Title', 'meditest-extra'),
                    'name'       => esc_html__('Name', 'meditest-extra'),
                    'rand'       => esc_html__('Random', 'meditest-extra'),
                    'ID'       => esc_html__('ID', 'meditest-extra'),
                ],
            ]
        );

        // Post Order

        $this->add_control(
            'post_order',
            [
                'type'    => Controls_Manager::SELECT,
                'label' => esc_html__('Post Ordering', 'meditest-extra'),
                'default' => 'DESC',
                'options' => [
                    'DESC' => esc_html__('Desecending', 'meditest-extra'),
                    'ASC' => esc_html__('Ascending', 'meditest-extra'),
                ],
            ]
        );


        // Post Categories

        $this->add_control(
            'post_cats',
            [
                'type'      => Controls_Manager::SELECT2,
                'label' => esc_html__('Select Categories', 'meditest-extra'),
                'options'   => $this->posts_cat_list(),
                'label_block' => true,
                'multiple'  => true,
            ]
        );

        $this->add_control(
            'post_tags',
            [
                'label' => esc_html__('Select tags', 'meditest-extra'),
                'type'      => Controls_Manager::SELECT2,
                'options'   => meditest_post_tags(),
                'label_block' => true,
                'multiple'  => true,
            ]
        );

        // Post Items.

        $this->add_control(
            'post_count',
            [
                'label'         => esc_html__('Number Of Posts', 'meditest-extra'),
                'type'          => Controls_Manager::NUMBER,
                'default'       => '3',
            ]
        );


        $this->add_control(
            'enable_offset_post',
            [
                'label' => esc_html__('Enable Skip Post', 'meditest-extra'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'meditest-extra'),
                'label_off' => esc_html__('No', 'meditest-extra'),
                'default' => 'no',

            ]
        );

        $this->add_control(
            'post_offset_count',
            [
                'label'         => esc_html__('Skip Post Count', 'meditest-extra'),
                'type'          => Controls_Manager::NUMBER,
                'default'       => '1',
                'condition' => ['enable_offset_post' => 'yes']

            ]
        );




        $this->end_controls_section();
    }

    /**
     * Meta Options
     */
    private function meta_options()
    {


        $this->start_controls_section(
            'meta_option',
            [
                'label' => __('Meta Options', 'meditest-extra'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );


        $this->add_control(
            'show_desc',
            [
                'label' => esc_html__('Display Post Excerpt', 'meditest-extra'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'meditest-extra'),
                'label_off' => esc_html__('No', 'meditest-extra'),
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'show_cat',
            [
                'label' => esc_html__('Display Category Name', 'meditest-extra'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'meditest-extra'),
                'label_off' => esc_html__('No', 'meditest-extra'),
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'show_comment',
            [
                'label' => esc_html__('Display Comment Count', 'meditest-extra'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'meditest-extra'),
                'label_off' => esc_html__('No', 'meditest-extra'),
                'default' => 'yes',
            ]
        );

        $this->end_controls_section();
    }

    /**
     * Design Options
     */
    private function design_options()
    {


        $this->start_controls_section(
            'design_option',
            [
                'label' => __('Typography', 'meditest-extra'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typo',
                'label' => esc_html__('Title Typography', 'meditest-extra'),
                'selector' => '{{WRAPPER}} .meditest-post-grid .news-post-grid-content h3.post-title',
            ]
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'excerpt_typo',
                'label' => esc_html__('Except Typography', 'meditest-extra'),
                'selector' => '{{WRAPPER}} .meditest-post-grid .news-post-grid-content .post-excerpt-box p',
            ]
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'author_typo',
                'label' => esc_html__('Author Name Typography', 'meditest-extra'),
                'selector' => '{{WRAPPER}} .meditest-post-grid .post-meta-left-content h4.post-author-name',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'cat_typo',
                'label' => esc_html__('Category Meta Typography', 'meditest-extra'),
                'selector' => '{{WRAPPER}} .meditest-post-grid .post-category-box.post-block-meta-cat',
            ]
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'more_link_typo',
                'label' => esc_html__('More Link Typography', 'meditest-extra'),
                'selector' => '{{WRAPPER}} .meditest-post-grid .post-meta-bottom-list-wrap .post-more-link',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'date_comment',
                'label' => esc_html__('Date & Comment', 'meditest-extra'),
                'selector' => '{{WRAPPER}} .meditest-post-grid .grid-content-meta-uniq .custom-meta-date-bx, {{WRAPPER}} .meditest-post-grid .grid-content-meta-uniq .cutom-comment-wrapper',
            ]
        );

        $this->add_control(
            'post_title_crop',
            [
                'label'         => esc_html__('Post Title Length', 'meditest-extra'),
                'type'          => Controls_Manager::NUMBER,
                'default'       => '10',
            ]
        );

        $this->add_control(
            'desc_limit',
            [
                'label'         => esc_html__('Post Excerpt Length', 'meditest-extra'),
                'type'          => Controls_Manager::NUMBER,
                'default'       => '15',
            ]
        );



        $this->end_controls_section();
    }



    protected function render()
    {
        $settings = $this->get_settings_for_display();

        $arg = [
            'post_type'   =>  'post',
            'post_status' => 'publish',
            'order' => $settings['post_order'],
            'posts_per_page' => $settings['post_count'],
            'tag__in' => $settings['post_tags'],
            'suppress_filters' => false,

        ];

        if ($settings['post_cats'] != '' && !empty($settings['post_cats'])) {

            $arg['tax_query'] = array(
                array(
                    'taxonomy' => 'category',
                    'terms'    => $settings['post_cats'],
                    'field' => 'id',
                    'include_children' => true,
                    'operator' => 'IN'
                ),
            );
        }

        switch ($settings['post_sortby']) {
            case 'mostdiscussed':
                $arg['orderby'] = 'comment_count';
                break;
            case 'title':
                $arg['orderby'] = 'title';
                break;
            case 'ID':
                $arg['orderby'] = 'ID';
                break;
            case 'rand':
                $arg['orderby'] = 'rand';
                break;
            case 'name':
                $arg['orderby'] = 'name';
                break;
            default:
                $arg['orderby'] = 'date';
                break;
        }

        // Post Offset		
        if ($settings['enable_offset_post'] == 'yes') {
            $arg['offset'] = $settings['post_offset_count'];
        }

        $query = new \WP_Query($arg);



?>


        <?php if ($query->have_posts()) { ?>


            

                    <?php

                    switch ($settings['layout_style']) {
                        case 'st_one':
                            meditest_latest_post_grid_one($settings, $query);
                            break;
                        case 'st_two':
                            meditest_latest_post_grid_two($settings, $query);
                            break;
                        case 'st_three':
                            meditest_latest_post_grid_three($settings, $query);
                            break;
                        case 'st_four':
                            meditest_latest_post_grid_four($settings, $query);
                            break;
                    }

                    ?>

                

        <?php } ?>


<?php }

    protected function content_template()
    {
    }

    public function posts_cat_list()
    {

        $terms = get_terms(array(
            'taxonomy'    => 'category',
            'hide_empty'  => false,
            'posts_per_page' => -1,
        ));

        $cat_list = [];
        foreach ($terms as $post) {
            $cat_list[$post->term_id]  = [$post->name];
        }
        return $cat_list;
    }
}



Plugin::instance()->widgets_manager->register_widget_type(new meditest_latest_post_grid());
