<?php

/**
 * Elementor Widget
 * @package Meditest
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class meditest_skills_progress_bar extends Widget_Base
{

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name()
	{
		return 'skill-progress-bar';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title()
	{
		return esc_html__('Skills Progress Bar', 'meditest-extra');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon()
	{
		return 'fas fa-th-large';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories()
	{
		return ['meditest_doctor_profile'];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */


	protected function register_controls()
	{
		$this->layout_options();
	}

	/**
	 * Layout Options
	 */
	private function layout_options()
	{


		$this->start_controls_section(
			'layout_option',
			[
				'label' => __('Layout Options', 'meditest-extra'),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);


		$this->add_control(
			'skill_title',
			[
				'label' => esc_html__('Skill Title', 'meditest-extra'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Dental  & Medical Services', 'meditest-extra'),
				'label_block' => true,
			]
		);

		$this->add_control(
			'skill_progress',
			[
				'label' => esc_html__('Skill Progress Percentage', 'meditest-extra'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('80', 'meditest-extra'),
				'label_block' => true,
			]
		);


		$this->add_control(
			'preogress_color',
			[
				'label' => esc_html__('Text Color', 'textdomain'),
				'type' => \Elementor\Controls_Manager::COLOR,
			]
		);

		$this->add_control(
			'circle_box_size',
			[
				'label' => esc_html__('Progress Circle Box Size', 'textdomain'),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 50,
						'max' => 1000,
						'step' => 1,
					],

				],
				'default' => [
					'size' => 100,
				],

			]
		);


		$this->end_controls_section();
	}

	protected function render()
	{

		$settings = $this->get_settings_for_display();

?>

		<script type="text/javascript">
			jQuery(document).ready(function($) {

				/* Circle Initialize */
				$(".progress-circle-box").circleChart();

			});
		</script>



		<div class="doctor-slills-probress-bar-wrap">
			<div class="doctor-skills-progress-bar-inner">

				<div class="progress-circle-box" data-size="<?php echo esc_attr($settings['circle_box_size']['size']); ?>" data-value="<?php echo esc_attr($settings['skill_progress']); ?>" data-text="<?php echo esc_attr($settings['skill_progress']); ?>%" data-color="<?php echo esc_attr($settings['preogress_color']); ?>" data-background="true"></div>
				<p class="skill-title"><?php echo $settings['skill_title']; ?></p>

			</div>
		</div>


<?php
	}
}

Plugin::instance()->widgets_manager->register_widget_type(new meditest_skills_progress_bar());
