<?php

/**
 * Elementor Widget
 * @package Meditest
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class meditest_team_box_block extends Widget_Base
{

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name()
	{
		return 'team-box-block';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title()
	{
		return esc_html__('Team Box Block', 'meditest-extra');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon()
	{
		return 'fas fa-th-large';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories()
	{
		return ['meditest_widgets'];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */


	protected function register_controls()
	{
		$this->layout_options();
		$this->style_options();
	}

	/**
	 * Layout Options
	 */
	private function layout_options()
	{


		$this->start_controls_section(
			'layout_option',
			[
				'label' => __('Layout Options', 'meditest-extra'),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'image',
			[
				'label' => esc_html__('Add Image', 'textdomain'),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'box_name',
			[
				'label' => esc_html__('Name', 'textdomain'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Jerome Bell', 'textdomain'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'box_title',
			[
				'label' => esc_html__('Title', 'textdomain'),
				'type' => Controls_Manager::TEXTAREA,
				'default' => esc_html__('Dental specialist', 'textdomain'),
			]
		);

		$this->add_control(
			'profile_select',
			[
				'label' => 'Select Doctor Profile Post',
				'type' => Controls_Manager::SELECT,
				'options' => $this->get_doctor_profile_posts(),
				'label_block' => true,
			]
		);


		$repeater = new Repeater();

		$repeater->add_control(
			'hidden_view',
			[
				'label' => esc_html__('View', 'textdomain'),
				'type' => \Elementor\Controls_Manager::HIDDEN,
				'default' => 'Social Profile Info',
			]
		);

		$repeater->add_control(
			'icon',
			[
				'label' => esc_html__('Icon', 'textdomain'),
				'type' => Controls_Manager::ICONS,
				'default' => [
					'value' => 'fas fa-facebook',
					'library' => 'fa-solid',
				],
			]
		);

		$repeater->add_control(
			'link_url',
			[
				'label' => esc_html__('Link', 'textdomain'),
				'type' => Controls_Manager::URL,
				'placeholder' => esc_html__('https://your-link.com', 'textdomain'),
				'dynamic' => [
					'active' => true,
				],
			]
		);

		$this->add_control(
			'social_lists',
			[
				'label' => esc_html__('Social Profiles', 'textdomain'),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'hidden_view' => esc_html__('Title #1', 'textdomain'),
					],
				],
				'title_field' => '{{{ hidden_view }}}',
			]
		);


		$this->end_controls_section();
	}


	/**
	 * Layout Options
	 */
	private function style_options()
	{


		$this->start_controls_section(
			'style_option',
			[
				'label' => __('Style Options', 'meditest-extra'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'icon_bg_color',
			[
				'label' => esc_html__('Icon Background Color', 'textdomain'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .service-icon-box-conent .icon-box-head .box-icon, 
					{{WRAPPER}} .service-two-icon-box-conent .box-two-icon,
					{{WRAPPER}} .service-three-icon-box-conent .box-three-icon' => 'background: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'icon_box_shasow',
			[
				'label' => esc_html__('Icon Background Shadow Color', 'textdomain'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .service-icon-box-conent .icon-box-head .box-icon, 
					{{WRAPPER}} .service-two-icon-box-conent .box-two-icon,
					{{WRAPPER}} .service-three-icon-box-conent .box-three-icon' => 'box-shadow: 0px 4px 40px -10px {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Title Typography', 'textdomain'),
				'name' => 'title_typo',
				'selector' => '{{WRAPPER}} .service-icon-box-conent .icon-box-head h3, 
				{{WRAPPER}} .service-two-icon-box-conent h3.sb-two-title,
				{{WRAPPER}} .service-three-icon-box-conent h3.sb-three-title',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Text Typography', 'textdomain'),
				'name' => 'text_typo',
				'selector' => '{{WRAPPER}} .service-icon-box-conent p, 
				{{WRAPPER}} .service-two-icon-box-conent p,
				{{WRAPPER}} .service-three-icon-box-conent p',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Link Typography', 'textdomain'),
				'name' => 'link_typo',
				'selector' => '{{WRAPPER}} .service-icon-box-conent a.icon-box-link, {{WRAPPER}} .service-two-icon-box-conent .service-two-icon-box-link, {{WRAPPER}} .service-two-icon-box-conent .service-two-icon-box-link i',
			]
		);



		$this->end_controls_section();
	}



	protected function render()
	{

		$settings = $this->get_settings_for_display();


?>

		<div class="team-box-block-section">
			<a class="profile_url" href="<?php echo esc_url(get_permalink($settings['profile_select'])); ?>"></a>
			<div class="team-box-block-content">
				<div class="team-specilist-img">
					<?php echo '<img src="' . $settings['image']['url'] . '">'; ?>

					<div class="team-sp-socials">
						<ul>
							<?php foreach ($settings['social_lists'] as $list) { ?>
								<li><a href="<?php echo esc_url($list['link_url']['url']) ?>"><?php Icons_Manager::render_icon($list['icon'], ['aria-hidden' => 'true']); ?></a></li>
							<?php } ?>
						</ul>
					</div>

				</div>

				<div class="team-sp-inner-info">
					<div class="team-specilist-info">
						<h3><?php echo wp_kses_post($settings['box_name']); ?></h3>
						<p><?php echo wp_kses_post($settings['box_title']); ?></p>
					</div>
					<div class="social-share">
						<i class="ri-share-fill"></i>
					</div>
				</div>


			</div>
		</div>



<?php
	}

	// Function to retrieve "doctorsprofile" posts
	protected function get_doctor_profile_posts()
	{
		$args = [
			'post_type' => 'doctorsprofile',
			'posts_per_page' => -1,
		];

		$doctorsprofiles = new \WP_Query($args);

		$profiles = [];

		if ($doctorsprofiles->have_posts()) {
			while ($doctorsprofiles->have_posts()) {
				$doctorsprofiles->the_post();
				$profiles[get_the_ID()] = get_the_title();
			}

			wp_reset_postdata();
		}

		return $profiles;
	}
}


Plugin::instance()->widgets_manager->register_widget_type(new meditest_team_box_block());
