<?php

/**
 * Elementor Widget
 * @package Meditest
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class meditest_unevent_review extends Widget_Base
{

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name()
	{
		return 'unevent-review';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title()
	{
		return esc_html__('Unevent Review', 'meditest-extra');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon()
	{
		return 'fas fa-th-large';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories()
	{
		return ['meditest_widgets'];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */


	protected function register_controls()
	{
		$this->layout_options();
		$this->style_options();
	}

	/**
	 * Layout Options
	 */
	private function layout_options()
	{


		$this->start_controls_section(
			'layout_option',
			[
				'label' => __('Layout Options', 'meditest-extra'),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);


		$repeater = new Repeater();


		$repeater->add_control(
			'rev_title',
			[
				'label' => esc_html__('Title', 'meditest-extra'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Best Service And 5 Stars', 'meditest-extra'),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'rev_description',
			[
				'label' => esc_html__('Description', 'meditest-extra'),
				'type' => Controls_Manager::TEXTAREA,
				'rows' => 6,
				'default' => esc_html__('hospitals are crucial institutions in our society', 'meditest-extra'),
			]
		);

		$repeater->add_control(
			'rev_rating',
			[
				'label' => esc_html__('Review Rating', 'textdomain'),
				'type' => Controls_Manager::NUMBER,
				'min' => 1,
				'max' => 5,
				'step' => 1,
				'default' => 5,
			]
		);

		$this->add_control(
			'unevent_rev_list',
			[
				'label' => esc_html__('Review List', 'meditest-extra'),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'rev_title' => esc_html__('Best Service And 5 Stars', 'meditest-extra'),
					],
				],
				'title_field' => '{{{ rev_title }}}',
			]
		);


		$this->end_controls_section();
	}

	/**
	 * Style Options
	 */
	private function style_options()
	{

		$this->start_controls_section(
			'style_option',
			[
				'label' => __('Style Options', 'meditest-extra'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'star_color',
			[
				'label' => esc_html__('Star Color', 'textdomain'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .unevent-rev-star-line i, {{WRAPPER}} .unevent-rev-star-fill i' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'rev_title_typo',
				'selector' => '{{WRAPPER}} .unevent-rev-inn h4.rev-title',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'rev_desc_typo',
				'selector' => '{{WRAPPER}} .unevent-rev-inn p.rev-text',
			]
		);


		$this->add_control(
			'rev_bg_color',
			[
				'label' => esc_html__('Background Color', 'textdomain'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .unevent-rev-inn' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_responsive_control(
			'rev_section_width',
			[
				'label' => esc_html__('Section Width', 'meditest-extra'),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
					],
				],
				'default'  => [
					'unit' => 'px',
					'size' => 260,
				],
				'selectors' => [
					'{{WRAPPER}} .unevent-rev-inn' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);


		$this->end_controls_section();
	}



	protected function render()
	{


		$settings = $this->get_settings_for_display();


?>


		<script type="text/javascript">
			jQuery(document).ready(function($) {

				/* Main Slider */
				$('.unevent-rev-section').slick({
					infinite: true,
					dots: false,
					arrows: false,
					autoplay: true,
					fade: true,
					speed: 800,
					slidesToShow: 1,
				});

			});
		</script>

		<div class="unevent-rev-section">
			<?php foreach ($settings['unevent_rev_list'] as $rev_list) { ?>
				<div class="unevent-review-content">
					<div class="unevent-rev-inn">
						<div class="unevent-rev-star-line">
							<?php for ($i = 0; $i < 5; $i++) {
								echo '<i class="ri-star-line"></i>';
							} ?>
						</div>
						<div class="unevent-rev-star-fill">
							<?php
							for ($r = 0; $r < $rev_list['rev_rating']; $r++) {
								echo '<i class="ri-star-fill"></i>';
							}
							?>
						</div>
						<h4 class="rev-title"><?php echo wp_kses_post($rev_list['rev_title']); ?></h4>
						<p class="rev-text"><?php echo wp_kses_post($rev_list['rev_description']); ?></p>
					</div>
				</div>

			<?php } ?>
		</div>

<?php
	}
}


Plugin::instance()->widgets_manager->register_widget_type(new meditest_unevent_review());
