<?php

/**
 * Elementor Widget
 * @package Meditest
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class meditest_appointment_btn extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'booking-buttton';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return esc_html__('Appointment Button', 'meditest-extra');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'fas fa-th-large';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['meditest_doctor_profile'];
    }

    /**
     * Register Elementor widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     * @access protected
     */


    protected function register_controls()
    {
        $this->layout_options();
        $this->style_options();
    }

    /**
     * Layout Options
     */
    private function layout_options()
    {


        $this->start_controls_section(
            'layout_option',
            [
                'label' => __('Layout Options', 'meditest-extra'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );


        $repeater = new Repeater();


        $repeater->add_control(
            'rev_title',
            [
                'label' => esc_html__('Title', 'meditest-extra'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Best Service And 5 Stars', 'meditest-extra'),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'rev_description',
            [
                'label' => esc_html__('Description', 'meditest-extra'),
                'type' => Controls_Manager::TEXTAREA,
                'rows' => 6,
                'default' => esc_html__('hospitals are crucial institutions in our society', 'meditest-extra'),
            ]
        );

        $repeater->add_control(
            'rev_rating',
            [
                'label' => esc_html__('Review Rating', 'textdomain'),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'max' => 5,
                'step' => 1,
                'default' => 5,
            ]
        );

        $this->add_control(
            'unevent_rev_list',
            [
                'label' => esc_html__('Review List', 'meditest-extra'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'rev_title' => esc_html__('Best Service And 5 Stars', 'meditest-extra'),
                    ],
                ],
                'title_field' => '{{{ rev_title }}}',
            ]
        );


        $this->end_controls_section();
    }

    /**
     * Style Options
     */
    private function style_options()
    {

        $this->start_controls_section(
            'style_option',
            [
                'label' => __('Style Options', 'meditest-extra'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'star_color',
            [
                'label' => esc_html__('Star Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .unevent-rev-star-line i, {{WRAPPER}} .unevent-rev-star-fill i' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'rev_title_typo',
                'selector' => '{{WRAPPER}} .unevent-rev-inn h4.rev-title',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'rev_desc_typo',
                'selector' => '{{WRAPPER}} .unevent-rev-inn p.rev-text',
            ]
        );


        $this->add_control(
            'rev_bg_color',
            [
                'label' => esc_html__('Background Color', 'textdomain'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .unevent-rev-inn' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'rev_section_width',
            [
                'label' => esc_html__('Section Width', 'meditest-extra'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                    ],
                ],
                'default'  => [
                    'unit' => 'px',
                    'size' => 260,
                ],
                'selectors' => [
                    '{{WRAPPER}} .unevent-rev-inn' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );


        $this->end_controls_section();
    }



    protected function render()
    {


        $settings = $this->get_settings_for_display();


        ?>

<div class="mt-plugin-container">


        <article id="post-<?php the_ID(); ?>"
                 class="em-service d-block text-center mt-4">
            <div class="service-two-icon-box-link">
                <button type="button"
                        class="btn btn-light mb-2 em-select-service-button"> <?php _e('Appointment', 'mt-service-booking'); ?> </button>
                <i class="icon-arrow-right1"></i>
            </div>
        </article>
</div>
        <!-- mt-reservation-process container -->
        <div class="em-reservation-process-container">
            <div class="em-reservation-div-position em-hide">
                <!-- All Selected Info  -->
                <div class="em-selected-all-wrapper">
                    <div class="em-selected-service">
                        <div class="em-get-selected-service em-service-excerpt d-flex align-items-center">

                        </div>
                        <button class="btn em-change-service-btn"> <?php _e('Change Service', 'mt-service-booking'); ?></button>
                    </div>
                    <div class="em-selected-date-wrapper">
                        <div class="em-selected-date d-flex align-items-center">
                            <label class="date"></label>
                            <button class="btn ml-sm-5 em-change-date-btn"> <?php _e('Change Date', 'mt-service-booking'); ?></button>
                        </div>
                    </div>
                    <div class="em-selected-time-slot-wrapper">
                        <div class="em-selected-time-slot d-flex align-items-center">
                            <label class="time-slot"></label>
                            <button class="btn ml-sm-5 em-change-time-slot-btn"> <?php _e('Change Slot', 'mt-service-booking'); ?></button>
                        </div>
                    </div>

                </div>

                <!-- All Selected Info Ends  -->

                <div class="em-calendar-wrapper">
                    <div class="mt-calender-loading-gif">
                        <img src="<?php echo plugin_dir_url(__FILE__) . 'assets/img/loading.gif'; ?>">
                    </div>
                    <div class="em-reservation-calendar"></div>
                </div>

                <div class="em-timer">
                    <div class="mt-loading-gif">
                        <img src="<?php echo plugin_dir_url(__FILE__) . 'assets/img/loading.gif'; ?>">
                    </div>
                    <div id="em-accordion" class="my-3 em-am-time ">
                        <div class="am-or-pm">
                            <button id="amButton" class="btn btn-light mb-2 em-am-button active mr-1">
                                <span> <?php _e('Before noon ( AM )', 'mt-service-booking'); ?></span></button>
                            <button id="pmButton" class="btn btn-light mb-2 em-pm-button ml-1">
                                <span> <?php _e('After noon ( PM ) ', 'mt-service-booking'); ?></span></button>
                        </div>

                        <div class="slots-container">

                            <ul class="slots list-group" id="emShowAM"></ul>
                            <ul class="slots list-group" id="emShowPM"></ul>
                        </div>
                    </div>

                </div>

                <div class="em-booking-form-container">
                    <form method="post" class="needs-validation"
                          novalidate <?php echo htmlspecialchars($_SERVER["PHP_SELF"]); ?>>
                        <div class="em-booking-form-fields">
                            <div class="form-row">
                                <div class="col-md-12 mb-3">
                                    <input name="mt_user_fullName" type="text" class="form-control"
                                           id="mt_user_fullName"
                                           placeholder="<?php _e('Your Full Name ', 'mt-service-booking'); ?>" value=""
                                           required>
                                    <div class="invalid-feedback">
                                        <?php _e('Please Enter Your Full Name ', 'mt-service-booking'); ?>
                                    </div>
                                </div>
                            </div>
                            <div class="form-row">
                                <div class="col-md-12 mb-3">
                                    <div>
                                        <input name="mt_user_email" type="email" class="form-control" id="mt_user_email"
                                               placeholder="<?php _e('Your Email Address ', 'mt-service-booking'); ?>"
                                               required>
                                        <div class="invalid-feedback">
                                            <?php _e('Please Enter a Valid Email Address ', 'mt-service-booking'); ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div class="form-row">
                                <div class="col-md-12 mb-3">
                                    <input name="mt_user_telephone" id="mt_user_telephone" type="tel" maxlength="25"
                                           size="40" class="form-control"
                                           placeholder="<?php _e('8801812345678 ', 'mt-service-booking'); ?>" required>
                                    <div class="invalid-feedback">
                                        <?php _e('Please Enter Your Valid Phone Number ', 'mt-service-booking'); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="mt-hidden-fields d-none">
                            <fieldset class="form-group">
                                <input type="number" name="mt_selected_service_id" id="mt_selected_service_id"
                                       value="112">
                                <input type="text" name="mt_selected_service" id="mt_selected_service"
                                       value="service-one">
                                <input type="text" name="mt_selected_service_title" id="mt_selected_service_title"
                                       value="">
                                <input type="text" name="mt_selected_service_location" id="mt_selected_service_location"
                                       value="service-one">
                                <input type="text" name="mt_selected_service_date_id" id="mt_selected_service_date_id"
                                       value="123123">
                                <input type="text" name="mt_selected_slot_id" id="mt_selected_slot_id" value="AM112">
                                <input type="text" name="mt_selected_service_provider_email"
                                       id="mt_selected_service_provider_email" value="xyz@gmail.com">
                                <input type="text" name="mt_selected_service_date" id="mt_selected_service_date"
                                       value="12/12/2019">
                                <input type="text" name="mt_selected_time_slot" id="mt_selected_time_slot"
                                       value="12:30 PM - 1:30 PM">
                                <input type="text" name="mt_selected_service_price" id="mt_selected_service_price"
                                       value="$1000">
                                <input type="number" name="mt_booking_slot_starts_at" id="mt_booking_slot_starts_at"
                                       value="">
                                <input type="number" name="mt_service_orders_per_slot" id="mt_service_orders_per_slot"
                                       value="">
                                <input type="number" name="mt_cookie_duration" id="mt_cookie_duration"
                                       value="<?php echo $customer_cookie_duration; ?>">
                                <input name="mt-create-nonce" id="mt-create-nonce"
                                       value="<?php echo wp_create_nonce("mt_booked_slot_nonce"); ?>">
                            </fieldset>
                        </div>

                        <button id="submitForm" class="btn btn-light em-confirm-booking-button" name="mt_submit_booking"
                                type="submit"
                                value="Submit"> <?php _e('Confirm Booking', 'mt-service-booking'); ?> </button>
                    </form>
                </div>

            </div>
        </div>
        <!-- mt-reservation-process container ends -->

     <?php
    }
}


Plugin::instance()->widgets_manager->register_widget_type(new meditest_appointment_btn());
