<?php

/**
 * Elementor Widget
 * @package Meditest
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class meditest_team_box_block_two extends Widget_Base
{

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name()
	{
		return 'team-box-block-two';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title()
	{
		return esc_html__('Team Box Block Two', 'meditest-extra');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon()
	{
		return 'fas fa-th-large';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories()
	{
		return ['meditest_widgets'];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */


	protected function register_controls()
	{
		$this->layout_options();
		$this->style_options();
	}

	/**
	 * Layout Options
	 */
	private function layout_options()
	{


		$this->start_controls_section(
			'layout_option',
			[
				'label' => __('Layout Options', 'meditest-extra'),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'image',
			[
				'label' => esc_html__('Add Image', 'textdomain'),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'box_name',
			[
				'label' => esc_html__('Name', 'textdomain'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Dr. Daisy Bins', 'textdomain'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'box_title',
			[
				'label' => esc_html__('Title', 'textdomain'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Dentist surgeon', 'textdomain'),
				'label_block' => true,
			]
		);
		$this->add_control(
			'box_text',
			[
				'label' => esc_html__('Short Description', 'textdomain'),
				'type' => Controls_Manager::TEXTAREA,
				'default' => esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit Nulla', 'textdomain'),
			]
		);


		$this->add_control(
			'link_text',
			[
				'label' => esc_html__('Link Text', 'textdomain'),
				'type' => Controls_Manager::TEXT,
				'default' => esc_html__('Read More', 'textdomain'),
			]
		);

		$this->add_control(
			'profile_select',
			[
				'label' => 'Select Doctor Profile Post',
				'type' => Controls_Manager::SELECT,
				'options' => $this->get_doctor_profile_posts(),
				'label_block' => true,
			]
		);


		$this->end_controls_section();
	}


	/**
	 * Layout Options
	 */
	private function style_options()
	{


		$this->start_controls_section(
			'style_option',
			[
				'label' => __('Style Options', 'meditest-extra'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Name Typography', 'textdomain'),
				'name' => 'name_typo',
				'selector' => '{{WRAPPER}} .service-two-icon-box-conent.team-info h3.team-name',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Title Typography', 'textdomain'),
				'name' => 'title_typo',
				'selector' => '{{WRAPPER}} .service-two-icon-box-conent.team-info p.designation',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Text Typography', 'textdomain'),
				'name' => 'text_typo',
				'selector' => '{{WRAPPER}} .service-two-icon-box-conent.team-info p',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => esc_html__('Link Typography', 'textdomain'),
				'name' => 'link_typo',
				'selector' => '{{WRAPPER}} .service-two-icon-box-conent .service-two-icon-box-link',
			]
		);



		$this->end_controls_section();
	}



	protected function render()
	{

		$settings = $this->get_settings_for_display();


?>


		<div class="team-box-block-two">
			<div class="service_slide_inner">
				<div class="team-info-box-section">
					<div class="team-box-img">
						<?php echo '<img src="' . $settings['image']['url'] . '">'; ?>
					</div>
					<div class="service-two-icon-box-conent team-info">
						<h3 class="team-name"><?php echo $settings['box_name']; ?></h3>
						<p class="designation"><?php echo $settings['box_title']; ?></p>
						<p><?php echo $settings['box_text']; ?></p>
						<div class="service-two-icon-box-link">
							<a href="<?php echo esc_url(get_permalink($settings['profile_select'])); ?>"><?php echo $settings['link_text']; ?> </a> <i class="icon-arrow-right1"></i>
						</div>
					</div>
				</div>
			</div>
		</div>

<?php
	}

	// Function to retrieve "doctorsprofile" posts
	protected function get_doctor_profile_posts()
	{
		$args = [
			'post_type' => 'doctorsprofile',
			'posts_per_page' => -1,
		];

		$doctorsprofiles = new \WP_Query($args);

		$profiles = [];

		if ($doctorsprofiles->have_posts()) {
			while ($doctorsprofiles->have_posts()) {
				$doctorsprofiles->the_post();
				$profiles[get_the_ID()] = get_the_title();
			}

			wp_reset_postdata();
		}

		return $profiles;
	}
}


Plugin::instance()->widgets_manager->register_widget_type(new meditest_team_box_block_two());
