<?php

/**
 * Meditest functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package meditest
 */


/**
 * define theme info
 * @since 1.0.0
 * */

if (is_child_theme()) {
	$theme = wp_get_theme();
	$parent_theme = $theme->Template;
	$theme_info = wp_get_theme($parent_theme);
} else {
	$theme_info = wp_get_theme();
}

define('MEDITEST_DEV_MODE', true);
$meditest_version = MEDITEST_DEV_MODE ? time() : $theme_info->get('Version');
define('MEDITEST_NAME', $theme_info->get('Name'));
define('MEDITEST_VERSION', $meditest_version);
define('MEDITEST_AUTHOR', $theme_info->get('Author'));
define('MEDITEST_AUTHOR_URI', $theme_info->get('AuthorURI'));


/**
 * Define Const for theme Dir
 * @since 1.0.0
 * */

define('MEDITEST_THEME_URI', get_template_directory_uri());
define('MEDITEST_IMG', MEDITEST_THEME_URI . '/assets/images');
define('MEDITEST_CSS', MEDITEST_THEME_URI . '/assets/css');
define('MEDITEST_JS', MEDITEST_THEME_URI . '/assets/js');
define('MEDITEST_THEME_DIR', get_template_directory());
define('MEDITEST_IMG_DIR', MEDITEST_THEME_DIR . '/assets/images');
define('MEDITEST_CSS_DIR', MEDITEST_THEME_DIR . '/assets/css');
define('MEDITEST_JS_DIR', MEDITEST_THEME_DIR . '/assets/js');
define('MEDITEST_INC', MEDITEST_THEME_DIR . '/inc');
define('MEDITEST_THEME_OPTIONS', MEDITEST_INC . '/theme-options');
define('MEDITEST_THEME_OPTIONS_IMG', MEDITEST_THEME_OPTIONS . '/img');

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */

function meditest_setup()
{

	// make the theme available for translation
	load_theme_textdomain('meditest', get_template_directory() . '/languages');

	// add support for post formats
	add_theme_support('post-formats', [
		'standard', 'image', 'video', 'audio', 'gallery'
	]);

	// add support for automatic feed links
	add_theme_support('automatic-feed-links');

	// let WordPress manage the document title
	add_theme_support('title-tag');

	// add editor style theme support
	function meditest_theme_add_editor_styles()
	{
		add_editor_style('custom-style.css');
	}
	add_action('admin_init', 'meditest_theme_add_editor_styles');

	// add support for post thumbnails
	add_theme_support('post-thumbnails');

	// hard crop center center
	set_post_thumbnail_size(823, 500, ['center', 'center']);

	// Custom header
	add_theme_support('custom-header');

	// register navigation menus
	register_nav_menus(
		[
			'primary' => esc_html__('Primary Menu', 'meditest'),
			'topmenu' => esc_html__('Top Menu', 'meditest'),
			'footermenu' => esc_html__('Footer Menu', 'meditest'),
		]
	);


	// HTML5 markup support for search form, comment form, and comments
	add_theme_support('html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
	));


	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 */
	add_theme_support('custom-logo', array(
		'height'      => 150,
		'width'       => 300,
		'flex-width'  => true,
		'flex-height' => true,
	));


	// Add theme support for selective refresh for widgets.
	add_theme_support('customize-selective-refresh-widgets');


	/*
     * Enable support for wide alignment class for Gutenberg blocks.
     */
	add_theme_support('align-wide');
	add_theme_support('editor-styles');
	add_theme_support('wp-block-styles');
}

add_action('after_setup_theme', 'meditest_setup');

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */

function meditest_widget_init()
{


	register_sidebar(array(
		'name' => esc_html__('Blog widget area', 'meditest'),
		'id' => 'sidebar-1',
		'description' => esc_html__('Blog Sidebar Widget.', 'meditest'),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',

	));
}

add_action('widgets_init', 'meditest_widget_init');


/**
 * Enqueue scripts and styles.
 */
function meditest_scripts()
{

	// Theme CSS 

	wp_enqueue_style('themefont-awesome', MEDITEST_CSS . '/font-awesome.css');
	wp_enqueue_style('icon-font',  MEDITEST_CSS . '/icon-font.css');
	wp_enqueue_style('icomoon-font',  MEDITEST_CSS . '/icomoon-font.css');
	wp_enqueue_style('remix-font',  MEDITEST_CSS . '/remixicon.css');
	wp_enqueue_style('animate',  MEDITEST_CSS . '/animate.css');
	wp_enqueue_style('magnific-popup',  MEDITEST_CSS . '/magnific-popup.css');
	wp_enqueue_style('owl-carousel',  MEDITEST_CSS . '/owl.carousel.min.css');
	wp_enqueue_style('owl-theme',  MEDITEST_CSS . '/owl.theme.min.css');
	wp_enqueue_style('slick',  MEDITEST_CSS . '/slick.css');
	wp_enqueue_style('slicknav',  MEDITEST_CSS . '/slicknav.css');
	wp_enqueue_style('bootstrap', MEDITEST_CSS . '/bootstrap.min.css', array(), '4.0', 'all');
	wp_enqueue_style('data-lity',  MEDITEST_CSS . '/lity.min.css');
	wp_enqueue_style('meditest-main',  MEDITEST_CSS . '/main.css');
	wp_enqueue_style('meditest-elements',  MEDITEST_CSS . '/elements-widget.css');
	wp_enqueue_style('meditest-responsive',  MEDITEST_CSS . '/responsive.css');

	wp_enqueue_style('meditest-style', get_stylesheet_uri());

	// Theme JS

	wp_enqueue_script('bootstrap',  MEDITEST_JS . '/bootstrap.min.js', array('jquery'),  '4.0', true);
	wp_enqueue_script('popper',  MEDITEST_JS . '/popper.min.js', array('jquery'),  '1.0', true);
	wp_enqueue_script('jquery-magnific-popup',  MEDITEST_JS . '/jquery.magnific-popup.min.js', array('jquery'),  '1.0', true);
	wp_enqueue_script('jquery-appear',  MEDITEST_JS . '/jquery.appear.min.js', array('jquery'),  '1.0', true);
	wp_enqueue_script('owl-carousel',  MEDITEST_JS . '/owl.carousel.min.js', array('jquery'),  '1.0', true);
	wp_enqueue_script('circle-chart',  MEDITEST_JS . '/circle-chart.min.js', array('jquery'),  '1.0', true);
	wp_enqueue_script('slick', MEDITEST_JS . '/slick.js', array('jquery'), '1.0', true);
	wp_enqueue_script('jquery-slicknav', MEDITEST_JS . '/jquery.slicknav.min.js', array('jquery'), '1.0', true);
	wp_enqueue_script('data-lity', MEDITEST_JS . '/lity.min.js', array('jquery'), '1.0', true);

	// Custom JS Scripts

	wp_enqueue_script('meditest-scripts',  MEDITEST_JS . '/scripts.js', array('jquery'),  '1.0', true);

	wp_localize_script('meditest-scripts', 'meditest_ajax', array(

		'ajax_url' => admin_url('admin-ajax.php'),

	));


	if (is_singular() && comments_open() && get_option('thread_comments')) {
		wp_enqueue_script('comment-reply');
	}
}

add_action('wp_enqueue_scripts', 'meditest_scripts');


if (!function_exists('meditest_extra_is_activated')) {
	/**
	 * Checks if Meditest Extra is activated
	 *
	 * @return boolean
	 */
	function meditest_extra_is_activated()
	{
		return class_exists('Meditest_Extra_Init') ? true : false;
	}
}

// Google Fonts
function meditest_google_fonts_url()
{
	$fonts_url = '';

	$googlefonts = _x('on', 'GoogleFonts: on or off', 'meditest');

	if ('off' !== $googlefonts) {
		$font_families = array();

		if ('off' !== $googlefonts) {
			$font_families[] = 'Inter:100,200,300,400,500,600,700,800,900';
		}

		$query_args = array(
			'family' => urlencode(implode('|', $font_families)),
			'subset' => urlencode('latin,latin-ext'),
		);
		$fonts_url = add_query_arg($query_args, 'https://fonts.googleapis.com/css');
	}
	return esc_url_raw($fonts_url);
}

function meditest_google_fonts_enqueue()
{
	wp_enqueue_style('meditest-google-fonts', meditest_google_fonts_url(), array(), null);
}
add_action('wp_enqueue_scripts', 'meditest_google_fonts_enqueue');

/*
* Include codester helper functions
* @since 1.0.0
*/

if (file_exists(MEDITEST_INC . '/cs-framework-functions.php')) {
	require_once  MEDITEST_INC . '/cs-framework-functions.php';
}

/**
 * Theme option panel & Metaboxes.
 */
if (file_exists(MEDITEST_THEME_OPTIONS . '/theme-options.php')) {
	require_once  MEDITEST_THEME_OPTIONS . '/theme-options.php';
}

if (file_exists(MEDITEST_THEME_OPTIONS . '/theme-metabox.php')) {
	require_once  MEDITEST_THEME_OPTIONS . '/theme-metabox.php';
}

if (file_exists(MEDITEST_THEME_OPTIONS . '/theme-customizer.php')) {
	require_once  MEDITEST_THEME_OPTIONS . '/theme-customizer.php';
}


if (file_exists(MEDITEST_THEME_OPTIONS . '/theme-inline-styles.php')) {
	require_once  MEDITEST_THEME_OPTIONS . '/theme-inline-styles.php';
}


/**
 * Required plugin installer 
 */
require get_template_directory() . '/inc/required-plugins.php';


/**
 * Custom template tags & functions for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';
require get_template_directory() . '/inc/template-functions.php';

// Theme Breadcrumb
if (file_exists(MEDITEST_INC . '/theme-breadcrumb.php')) {
	require_once  MEDITEST_INC . '/theme-breadcrumb.php';
}

/**
 * Load WooCommerce compatibility file.
 */
if (class_exists('WooCommerce')) {
	require get_template_directory() . '/inc/woocommerce.php';
}

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function meditest_content_width()
{
	$GLOBALS['content_width'] = apply_filters('meditest_content_width', 640);
}

add_action('after_setup_theme', 'meditest_content_width', 0);

/**
 * Nav menu fallback function
 */

function meditest_fallback_menu()
{
	get_template_part('template-parts/default', 'menu');
}

function meditest_admin_style()
{
	wp_enqueue_style('theme-admin-style',  MEDITEST_CSS . '/admin-style.css');
}

add_action('admin_enqueue_scripts', 'meditest_admin_style');


/**
 * Post List Load More Function
 */

function meditest_post_ajax_loading_cb()
{
	$settings =  $_POST['ajax_json_data'];
	//$show_gradient = (($settings['show_gradient']== 'yes') ? 'gradient-post' : '');

	$arg = [
		'post_type'   =>  'post',
		'post_status' => 'publish',
		'order'       => $settings['order'],
		'posts_per_page' => $settings['posts_per_page'],
		'paged'             => $_POST['paged'],
		'tag__in'           => $settings['tags'],
		'suppress_filters' => false,

	];

	if (count($settings['terms'])) {
		$arg['tax_query'] = array(
			array(
				'taxonomy' => 'category',
				'terms'    => $settings['terms'],
				'field' => 'id',
				'include_children' => true,
				'operator' => 'IN'
			),
		);
	}

	switch ($settings['post_sortby']) {

		case 'title':
			$arg['orderby'] = 'title';
			break;


		case 'mostdiscussed':
			$arg['orderby'] = 'comment_count';
			break;
		default:
			$arg['orderby'] = 'date';
			break;
	}

	$allpostloding = new WP_Query($arg);
	$index = 0;

?>
	<div class="row">

		<?php
		while ($allpostloding->have_posts()) {
			$allpostloding->the_post(); ?>

			<div class="col-lg-4">

				<div class="post-block-item-one post-block-col-one">

					<div class="news-post-grid-thumbnail">
						<a href="<?php the_permalink(); ?>" class="news-post-grid-thumbnail-wrap">
							<img src="<?php echo esc_attr(esc_url(get_the_post_thumbnail_url(null, 'full'))); ?>" alt="<?php the_title_attribute(); ?>">
						</a>
					</div>

					<div class="news-post-grid-content grid-content-inner">


						<?php if ($settings['show_cat'] == 'yes') : ?>
							<div class="post-category-box post-block-meta-cat">
								<?php require MEDITEST_THEME_DIR . '/template-parts/cat-alt-template.php'; ?>
							</div>
						<?php endif; ?>

						<h3 class="post-title">
							<a href="<?php the_permalink(); ?>"><?php echo esc_html(wp_trim_words(get_the_title(), $settings['post_title_crop'], '')); ?></a>
						</h3>

						<?php if ($settings['show_desc'] == 'yes') : ?>
							<div class="post-excerpt-box">
								<p><?php echo esc_html(wp_trim_words(get_the_excerpt(), $settings['desc_limit'], '')); ?></p>
							</div>
						<?php endif; ?>

						<div class="post-meta-bottom-list-wrap cols-post-meta-items">
							<div class="post-meta-left-wrap cols-meta-left">
								<div class="post-meta-left-author">
									<?php echo get_avatar(get_the_author_meta('ID'), 62); ?>
								</div>

								<div class="post-meta-left-content">

									<?php if ($settings['show_author'] == 'yes') : ?>
										<h4 class="post-author-name">
											<?php echo get_the_author_link(); ?>
										</h4>
									<?php endif; ?>

									<ul class="post-bottom-meta-list">

										<?php if ($settings['show_date'] == 'yes') : ?>
											<li class="post-meta-date"><?php echo esc_html(get_the_date('F j, Y')); ?></li>
										<?php endif; ?>

										<?php if ($settings['show_read_time'] == 'yes') : ?>
											<li class="post-meta-time"><?php echo meditest_reading_time(); ?></li>
										<?php endif; ?>


									</ul>
								</div>
							</div>
						</div>
					</div>

				</div>

			</div>

		<?php
			$index++;
		}

		?>
	</div>

<?php
	wp_reset_postdata();
	wp_die();
}

add_action('wp_ajax_nopriv_meditest_post_ajax_loading', 'meditest_post_ajax_loading_cb');
add_action('wp_ajax_meditest_post_ajax_loading', 'meditest_post_ajax_loading_cb');
