<?php
/*
 * Theme Metabox
 * @package Meditest
 * @since 1.0.0
 * */

if (!defined('ABSPATH')) {
	exit(); // exit if access directly
}

if (class_exists('CSF')) {

	$prefix = 'meditest';

	/*-------------------------------------
		Category Taxonomy Options
	-------------------------------------*/


	// Create taxonomy options
	CSF::createTaxonomyOptions($prefix, array(
		'title'     => esc_html__('Catgeory Options', 'meditest'),
		'taxonomy'  => 'category',
		'data_type' => 'serialize', // The type of the database save options. `serialize` or `unserialize`
	));

	//
	// Create a section
	CSF::createSection($prefix, array(
		'fields' => array(

			array(

				'id'          => 'cat-color',
				'type'        => 'color',
				'title'       => esc_html__('Select Category Color', 'meditest'),
				'default' => '#5E5EEE',

			),

			array(
				'id' => 'meditest_cat_layout',
				'type' => 'image_select',
				'title' => esc_html__('Select Category Layout', 'meditest'),
				'options' => array(
					'catt-one' => MEDITEST_IMG . '/admin/page/style1.png',
					'catt-two' => MEDITEST_IMG . '/admin/page/style2.png',
				),
				'default' => 'catt-one'
			),

		)
	));


	/*-------------------------------------
		Post Format Options
	-------------------------------------*/
	CSF::createMetabox('theme_postvideo_options', array(
		'title' => esc_html__('Video Post Format Options', 'meditest'),
		'post_type' => 'post',
		'post_formats' => 'video',
		'data_type'          => 'serialize',
		'context'            => 'advanced',
		'priority'           => 'default',
	));

	CSF::createSection('theme_postvideo_options', array(
		'fields' => array(
			array(
				'id' => 'textm',
				'type' => 'text',
				'title' => esc_html__('Upload Video For Post', 'meditest'),
				'desc' => esc_html__('Upload Video Post', 'meditest'),
			)
		)
	));


	/*-------------------------------------
       Page Options
   -------------------------------------*/
	$post_metabox = 'meditest_post_meta';

	CSF::createMetabox($post_metabox, array(
		'title'     => esc_html__('Page Options', 'meditest'),
		'post_type' => 'page',
	));

	//
	// Create a section
	CSF::createSection($post_metabox, array(
		'fields' => array(

			// nav select
			array(
				'id' => 'page_nav_menu',
				'type' => 'image_select',
				'title' => esc_html__('Select Header Navigation Style', 'meditest'),
				'subtitle' => esc_html__('If you want to show different header in different pages then select Header style from here.', 'meditest'),
				'options' => array(
					'nav-style-one' => MEDITEST_IMG . '/admin/header-style/style1.png',
					'nav-style-two' => MEDITEST_IMG . '/admin/header-style/style2.png',
					'nav-style-three' => MEDITEST_IMG . '/admin/header-style/style3.png',
				),
				'default'   => 'nav-style-one',
			),

			array(
				'id' => 'page_title_enable',
				'title' => esc_html__('Show Page Title', 'meditest'),
				'type' => 'switcher',
				'default' => true,
				'desc' => esc_html__('Show Page Title Bar', 'meditest'),
			),

			array(
				'id' => 'page-spacing-padding',
				'type' => 'spacing',
				'title' => esc_html__('Theme Page Spacing', 'meditest'),
				'output' => 'body.page .main-container',
				'output_mode' => 'padding', // or margin, relative
				'default' => array(
					'top' => '80',
					'right' => '0',
					'bottom' => '80',
					'left' => '0',
					'unit' => 'px',
				),
			),


		)
	));
}//endif