<?php

/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package meditest
 */

$blog_title = meditest_get_option('blog_title');
$blog_breadcrumb = meditest_get_option('blog_breadcrumb_enable', true);

get_header();

?>

<?php if ($blog_breadcrumb == true) : ?>
	<!-- Blog Breadcrumb -->
	<div class="theme-breadcrumb__Wrapper theme-breacrumb-area">
		<div class="container">
			<div class="row justify-content-center">
				<div class="col-lg-12">

					<h1 class="theme-breacrumb-title">

						<?php if (!empty($blog_title)) {
							echo esc_html($blog_title);
						} else {
							echo esc_html_e('Blog Page', 'meditest');
						} ?>
					</h1>
					<div class="breaccrumb-inner">
						<?php
						if (function_exists('the_meditest_breadcrumb')) {
							the_meditest_breadcrumb();
						}
						?>
					</div>
				</div>
			</div>
		</div>
	</div>
	<!-- Blog Breadcrumb End -->
<?php endif; ?>

<section id="main-content" class="blog main-container blog-spacing" role="main">
	<div class="container">
		<div class="row">
			<div class="<?php if (is_active_sidebar('sidebar-1')) {
							echo "col-lg-9";
						} else {
							echo "col-lg-12";
						} ?> col-md-12">
				<div class="category-layout-two main-blog-layout blog-new-layout theme-layout-mainn">
					<?php if (have_posts()) : ?>


						<?php

						$meditest_blog_global = meditest_get_option('meditest_blog_layout'); //for global	  
						if (class_exists('CSF') && !empty($meditest_blog_global)) {

							get_template_part('template-parts/category-templates/' . $meditest_blog_global . '');
						} else {

							get_template_part('template-parts/category-templates/catt-one');
						}
						?>

						<div class="theme-pagination-style">
							<?php
							the_posts_pagination(array(
								'next_text' => '<i class="icofont-long-arrow-right"></i>',
								'prev_text' => '<i class="icofont-long-arrow-left"></i>',
								'screen_reader_text' => ' ',
								'type'               => 'list'
							));
							?>
						</div>

					<?php else : ?>
						<?php get_template_part('template-parts/content', 'none'); ?>
					<?php endif; ?>

				</div>
			</div>

			<?php get_sidebar(); ?>

		</div>
	</div>
</section>

<?php get_footer();
